@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <string.h>
 #include <limits.h>
@@ -580,7 +580,7 @@ map_add_engine (PangoMapInfo    *info,
       if (is_exact)
 	entry->exact = g_slist_prepend (entry->exact, pair);
       else
-	entry->exact = g_slist_prepend (entry->fallback, pair);
+	entry->fallback = g_slist_prepend (entry->fallback, pair);
     }
 }
 
