@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <string.h>
 #include <stdlib.h>
 
@@ -107,19 +107,18 @@ pango_context_finalize (GObject *object)
 /**
  * pango_context_new:
  *
- * Creates a new #PangoContext initialized to default value.
+ * Creates a new #PangoContext initialized to default values.
  *
- * This function is only useful when implementing a new backend
- * for Pango, something applications won't do. You should use
- * the context creation function for the backend you are using,
- * for example, pango_cairo_font_map_create_context(), pango_xft_get_context(),
- * pango_win32_get_context() or, pango_ft2_font_map_create_context().
+ * This function is not particularly useful as it should always
+ * be followed by a pango_context_set_font_map() call, and the
+ * function pango_font_map_create_context() does these two steps
+ * together and hence users are recommended to use that.
  *
  * If you are using Pango as part of a higher-level system,
- * that system may have it's own ways of create a #PangoContext.
+ * that system may have it's own way of create a #PangoContext.
  * For instance, the GTK+ toolkit has, among others,
  * gdk_pango_context_get_for_screen(), and
- * gtk_widget_get_pango_context().
+ * gtk_widget_get_pango_context().  Use those instead.
  *
  * Return value: the newly allocated #PangoContext, which should
  *               be freed with g_object_unref().
@@ -280,7 +279,7 @@ pango_context_list_families (PangoContext          *context,
  * Loads the font in one of the fontmaps in the context
  * that is the closest match for @desc.
  *
- * Returns the font loaded, or %NULL if no font matched.
+ * Returns: the font loaded, or %NULL if no font matched.
  **/
 PangoFont *
 pango_context_load_font (PangoContext               *context,
@@ -301,7 +300,7 @@ pango_context_load_font (PangoContext               *context,
  * Load a set of fonts in the context that can be used to render
  * a font matching @desc.
  *
- * Returns the fontset, or %NULL if no font matched.
+ * Returns: the fontset, or %NULL if no font matched.
  **/
 PangoFontset *
 pango_context_load_fontset (PangoContext               *context,
@@ -763,7 +762,7 @@ update_attr_iterator (ItemizeState *state)
   state->gravity = attr == NULL ? PANGO_GRAVITY_AUTO : ((PangoAttrInt *)attr)->value;
 
   attr = find_attribute (state->extra_attrs, PANGO_ATTR_GRAVITY_HINT);
-  state->gravity_hint = attr == NULL ? state->context->gravity_hint : ((PangoAttrInt *)attr)->value;
+  state->gravity_hint = attr == NULL ? state->context->gravity_hint : (PangoGravityHint)((PangoAttrInt *)attr)->value;
 
   state->changed |= FONT_CHANGED;
   if (state->lang != old_lang)
@@ -1059,7 +1058,7 @@ typedef struct {
 } GetShaperFontInfo;
 
 static gboolean
-get_shaper_and_font_foreach (PangoFontset *fontset,
+get_shaper_and_font_foreach (PangoFontset *fontset G_GNUC_UNUSED,
 			     PangoFont    *font,
 			     gpointer      data)
 {
@@ -1339,7 +1338,7 @@ itemize_state_process_run (ItemizeState *state)
        *
        * The exception of PrivateUse and Unassigned characters is necessary
        * to be able to render any of them. (for private or being encoded
-       * scripts, etc.)
+       * scripts, etc.) (Recent glib returns true in isprint for PrivateUse.)
        */
       if (wc == 0x0020 ||
 	  G_UNLIKELY (!g_unichar_isprint (wc) &&
@@ -1623,13 +1622,13 @@ update_metrics_from_items (PangoFontMetrics *metrics,
 /**
  * pango_context_get_metrics:
  * @context: a #PangoContext
- * @desc: a #PangoFontDescription structure
+ * @desc: a #PangoFontDescription structure.  %NULL means that the font
+ * 	      description from the context will be used.
  * @language: language tag used to determine which script to get the metrics
  *            for. %NULL means that the language tag from the context will
  *            be used. If no language tag is set on the context, metrics
- *            large enough to cover a range of languages will be returned.
- *            The process of determining such metrics is slow, so it is best
- *            to always make sure some real language tag will be used.
+ *            for the default language (as determined by
+ *            pango_language_get_default()) will be returned.
  *
  * Get overall metric information for a particular font
  * description.  Since the metrics may be substantially different for
@@ -1658,7 +1657,9 @@ pango_context_get_metrics (PangoContext                 *context,
   GList *items;
 
   g_return_val_if_fail (PANGO_IS_CONTEXT (context), NULL);
-  g_return_val_if_fail (desc != NULL, NULL);
+
+  if (!desc)
+    desc = context->font_desc;
 
   if (!language)
     language = context->language;
