@@ -111,6 +111,7 @@ done:
 
   if (G_UNLIKELY (cf_priv->scaled_font == NULL || cairo_scaled_font_status (cf_priv->scaled_font) != CAIRO_STATUS_SUCCESS))
     {
+      cairo_scaled_font_t *scaled_font = cf_priv->scaled_font;
       PangoFont *font = PANGO_FONT (cf_priv->cfont);
       static GQuark warned_quark = 0;
       if (!warned_quark)
@@ -129,6 +130,18 @@ done:
 		     font_face ? "scaled font" : "font face",
 		     s);
 
+	  if (!font_face)
+		g_warning ("font_face is NULL");
+	  else
+		g_warning ("font_font status is: %s",
+			   cairo_status_to_string (cairo_font_face_status (font_face)));
+
+	  if (!scaled_font)
+		g_warning ("scaled_font is NULL");
+	  else
+		g_warning ("scaled_font status is: %s",
+			   cairo_status_to_string (cairo_scaled_font_status (scaled_font)));
+
 	  g_free (s);
 
 	  g_object_set_qdata_full (G_OBJECT (font), warned_quark,
@@ -223,17 +236,24 @@ _pango_cairo_font_get_metrics (PangoFont     *font,
 
   if (!tmp_list)
     {
+      PangoFontMap *fontmap;
       PangoContext *context;
       cairo_font_options_t *font_options;
       int height, shift;
 
+      /* XXX this is racy.  need a ref'ing getter... */
+      fontmap = pango_font_get_font_map (font);
+      if (!fontmap)
+        return pango_font_metrics_new ();
+      fontmap = g_object_ref (fontmap);
+
       info = g_slice_new0 (PangoCairoFontMetricsInfo);
 
       cf_priv->metrics_by_lang = g_slist_prepend (cf_priv->metrics_by_lang, info);
 
       info->sample_str = sample_str;
 
-      context = pango_font_map_create_context (pango_font_get_font_map (font));
+      context = pango_font_map_create_context (fontmap);
       pango_context_set_language (context, language);
       font_options = cairo_font_options_create ();
       cairo_scaled_font_get_font_options (_pango_cairo_font_private_get_scaled_font (cf_priv), font_options);
@@ -271,6 +291,7 @@ _pango_cairo_font_get_metrics (PangoFont     *font,
       info->metrics->ascent = height - info->metrics->descent;
 
       g_object_unref (context);
+      g_object_unref (fontmap);
     }
 
   return pango_font_metrics_ref (info->metrics);
@@ -356,10 +377,14 @@ _pango_cairo_font_private_get_hex_box_info (PangoCairoFontPrivate *cf_priv)
 
   /* create mini_font description */
   {
-    PangoContext *context;
     PangoFontMap *fontmap;
+    PangoContext *context;
 
+    /* XXX this is racy.  need a ref'ing getter... */
     fontmap = pango_font_get_font_map ((PangoFont *)cf_priv->cfont);
+    if (!fontmap)
+      return NULL;
+    fontmap = g_object_ref (fontmap);
 
     /* we inherit most font properties for the mini font.  just
      * change family and size.  means, you get bold hex digits
@@ -396,6 +421,7 @@ _pango_cairo_font_private_get_hex_box_info (PangoCairoFontPrivate *cf_priv)
     mini_font = pango_font_map_load_font (fontmap, context, desc);
 
     g_object_unref (context);
+    g_object_unref (fontmap);
   }
 
   pango_font_description_free (desc);
@@ -547,14 +573,18 @@ _pango_cairo_font_private_finalize (PangoCairoFontPrivate *cf_priv)
 
   if (cf_priv->scaled_font)
     cairo_scaled_font_destroy (cf_priv->scaled_font);
+  cf_priv->scaled_font = NULL;
 
   _pango_cairo_font_hex_box_info_destroy (cf_priv->hbi);
+  cf_priv->hbi = NULL;
 
   if (cf_priv->glyph_extents_cache)
     g_free (cf_priv->glyph_extents_cache);
+  cf_priv->glyph_extents_cache = NULL;
 
   g_slist_foreach (cf_priv->metrics_by_lang, (GFunc)free_metrics_info, NULL);
   g_slist_free (cf_priv->metrics_by_lang);
+  cf_priv->metrics_by_lang = NULL;
 }
 
 gboolean
