@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "pangocairo.h"
 #include "pangocairo-private.h"
@@ -187,7 +187,8 @@ pango_cairo_font_map_get_default (void)
  * default fontmap uses for example.  The old default font map
  * is unreffed and the new font map referenced.
  *
- * A value of %NULL for @fontmap will cause a new default font
+ * A value of %NULL for @fontmap will cause the current default
+ * font map to be released and a new default font
  * map to be created on demand, using pango_cairo_font_map_new().
  *
  * Since: 1.22
@@ -195,7 +196,7 @@ pango_cairo_font_map_get_default (void)
 void
 pango_cairo_font_map_set_default (PangoCairoFontMap *fontmap)
 {
-  g_return_if_fail (PANGO_IS_CAIRO_FONT_MAP (fontmap));
+  g_return_if_fail (fontmap == NULL || PANGO_IS_CAIRO_FONT_MAP (fontmap));
 
   if ((PangoFontMap *) fontmap == default_font_map)
     return;
@@ -203,7 +204,9 @@ pango_cairo_font_map_set_default (PangoCairoFontMap *fontmap)
   if (default_font_map)
     g_object_unref (default_font_map);
 
-  default_font_map = g_object_ref (fontmap);
+  if (fontmap)
+    g_object_ref (fontmap);
+  default_font_map = fontmap;
 }
 
 /**
@@ -255,18 +258,15 @@ pango_cairo_font_map_get_resolution (PangoCairoFontMap *fontmap)
  * Return value: the newly created context; free with g_object_unref().
  *
  * Since: 1.10
+ *
+ * Deprecated: 1.22: Use pango_font_map_create_context() instead.
  **/
 PangoContext *
 pango_cairo_font_map_create_context (PangoCairoFontMap *fontmap)
 {
-  PangoContext *context;
-
   g_return_val_if_fail (PANGO_IS_CAIRO_FONT_MAP (fontmap), NULL);
 
-  context = pango_context_new ();
-  pango_context_set_font_map (context, PANGO_FONT_MAP (fontmap));
-
-  return context;
+  return pango_font_map_create_context (PANGO_FONT_MAP (fontmap));
 }
 
 /**
