@@ -150,7 +150,7 @@ pango_cairo_win32_font_create_metrics_for_context (PangoCairoFont *font,
   pango_layout_set_text (layout, sample_str, -1);
   pango_layout_get_extents (layout, NULL, &extents);
 
-  metrics->approximate_char_width = extents.width / g_utf8_strlen (sample_str, -1);
+  metrics->approximate_char_width = extents.width / pango_utf8_strwidth (sample_str);
 
   pango_layout_set_text (layout, "0123456789", -1);
   metrics->approximate_digit_width = max_glyph_width (layout);
@@ -164,6 +164,10 @@ pango_cairo_win32_font_create_metrics_for_context (PangoCairoFont *font,
 static void
 pango_cairo_win32_font_finalize (GObject *object)
 {
+  PangoCairoWin32Font *cwfont = (PangoCairoWin32Font *) object;
+
+  _pango_cairo_font_private_finalize (&cwfont->cf_priv);
+
   G_OBJECT_CLASS (pango_cairo_win32_font_parent_class)->finalize (object);
 }
 
@@ -225,7 +229,7 @@ pango_cairo_win32_font_class_init (PangoCairoWin32FontClass *class)
 }
 
 static void
-pango_cairo_win32_font_init (PangoCairoWin32Font *cwfont)
+pango_cairo_win32_font_init (PangoCairoWin32Font *cwfont G_GNUC_UNUSED)
 {
 }
 
@@ -288,8 +292,9 @@ _pango_cairo_win32_font_new (PangoCairoWin32FontMap     *cwfontmap,
   cwfont = g_object_new (PANGO_TYPE_CAIRO_WIN32_FONT, NULL);
   win32font = PANGO_WIN32_FONT (cwfont);
 
-  win32font->fontmap = PANGO_FONT_MAP (cwfontmap);
-  g_object_ref (cwfontmap);
+  g_assert (win32font->fontmap == NULL);
+  win32font->fontmap = (PangoFontMap *) cwfontmap;
+  g_object_add_weak_pointer (G_OBJECT (win32font->fontmap), (gpointer *) (gpointer) &win32font->fontmap);
 
   win32font->win32face = face;
 
