@@ -496,7 +496,7 @@ pango_fc_font_create_metrics_for_context (PangoFcFont   *fcfont,
   pango_layout_get_extents (layout, NULL, &extents);
 
   metrics->approximate_char_width =
-    extents.width / g_utf8_strlen (sample_str, -1);
+    extents.width / pango_utf8_strwidth (sample_str);
 
   pango_layout_set_text (layout, "0123456789", -1);
   metrics->approximate_digit_width = max_glyph_width (layout);
