@@ -484,7 +484,10 @@ pango_fc_font_map_finalize (GObject *object)
   PangoFcFontMap *fcfontmap = PANGO_FC_FONT_MAP (object);
   PangoFcFontMapPrivate *priv = fcfontmap->priv;
 
-  pango_fc_font_map_cache_clear (fcfontmap);
+
+  /* Shutdown, so we clear the fonts and mark them as shut down */
+  pango_fc_font_map_shutdown (fcfontmap);
+
   g_queue_free (priv->fontset_cache);
   g_hash_table_destroy (priv->coverage_hash);
 
@@ -554,8 +557,11 @@ pango_fc_font_map_add (PangoFcFontMap *fcfontmap,
   FontHashKey *key_copy;
 
   g_assert (fcfont->fontmap == NULL);
-
-  fcfont->fontmap = g_object_ref (fcfontmap);
+  fcfont->fontmap = (PangoFontMap *) fcfontmap;
+  /* In other fontmaps we add a weak pointer on ->fontmap so the
+   * field is unset when fontmap is finalized.  We don't need it
+   * here though as PangoFcFontMap already cleans up fcfont->fontmap
+   * as part of it's caching scheme. */
 
   font_hash_key_for_context (fcfontmap, context, &key);
   key.pattern = fcfont->font_pattern;
@@ -597,7 +603,6 @@ _pango_fc_font_map_remove (PangoFcFontMap *fcfontmap,
   g_hash_table_remove (priv->font_hash, &key);
   fcfont->fontmap = NULL;
   _pango_fc_font_set_context_key (fcfont, NULL);
-  g_object_unref (fcfontmap);
 }
 
 static PangoFcFamily *
@@ -795,6 +800,7 @@ pango_fc_make_pattern (const  PangoFontDescription *description,
 		       double                       dpi)
 {
   FcPattern *pattern;
+  const char *prgname;
   int slant;
   int weight;
   PangoGravity gravity;
@@ -805,6 +811,7 @@ pango_fc_make_pattern (const  PangoFontDescription *description,
   int width;
 #endif
 
+  prgname = g_get_prgname ();
   slant = pango_fc_convert_slant_to_fc (pango_font_description_get_style (description));
   weight = pango_fc_convert_weight_to_fc (pango_font_description_get_weight (description));
 #ifdef FC_WIDTH
@@ -852,6 +859,9 @@ pango_fc_make_pattern (const  PangoFontDescription *description,
       FcPatternAddString (pattern, PANGO_FC_GRAVITY, value->value_nick);
     }
 
+  if (prgname)
+    FcPatternAddString (pattern, PANGO_FC_PRGNAME, prgname);
+
   return pattern;
 }
 
@@ -1415,12 +1425,11 @@ _pango_fc_font_map_fc_to_coverage (FcCharSet *charset)
  * needed for correct operation on the #PangoContext after calling
  * this function.
  *
- * As of Pango 1.20 this function is deprecated.
- * Use pango_font_map_create_context() instead.
- *
  * Return value: a new #PangoContext
  *
  * Since: 1.4
+ *
+ * Deprecated: 1.22: Use pango_font_map_create_context() instead.
  **/
 PangoContext *
 pango_fc_font_map_create_context (PangoFcFontMap *fcfontmap)
@@ -1436,7 +1445,6 @@ cleanup_font (gpointer        key,
 {
   _pango_fc_font_shutdown (fcfont);
 
-  g_object_unref (fcfont->fontmap);
   fcfont->fontmap = NULL;
 }
 
