@@ -143,7 +143,9 @@ struct _PangoFcFontMapClass
   void (*_pango_reserved4) (void);
 };
 
+#ifndef PANGO_DISABLE_DEPRECATED
 PangoContext * pango_fc_font_map_create_context (PangoFcFontMap *fcfontmap);
+#endif
 void           pango_fc_font_map_shutdown       (PangoFcFontMap *fcfontmap);
 
 #endif
@@ -181,6 +183,8 @@ PangoFontDescription *pango_fc_font_description_from_pattern (FcPattern *pattern
  * than %PangoGravitySouth is desired.
  *
  * The property will have a #PangoGravity value as a string, like "east".
+ * This can be used to write fontconfig configuration rules to choose
+ * different fonts for horizontal and vertical writing directions.
  *
  * Since: 1.20
  */
@@ -194,11 +198,29 @@ PangoFontDescription *pango_fc_font_description_from_pattern (FcPattern *pattern
  *
  * The property will have an integer value equal to what
  * pango_version() returns.
+ * This can be used to write fontconfig configuration rules that only affect
+ * certain pango versions (or only pango-using applications, or only
+ * non-pango-using applications).
  *
  * Since: 1.20
  */
 #define PANGO_FC_VERSION "pangoversion"
 
+/**
+ * PANGO_FC_PRGNAME:
+ *
+ * String representing a fontconfig property name that Pango sets on any
+ * fontconfig pattern it passes to fontconfig.
+ *
+ * The property will have a string equal to what
+ * g_get_prgname() returns.
+ * This can be used to write fontconfig configuration rules that only affect
+ * certain applications.
+ *
+ * Since: 1.24
+ */
+#define PANGO_FC_PRGNAME "pangoprgname"
+
 G_END_DECLS
 
 #endif /* __PANGO_FC_FONT_MAP_H__ */
